@@ -14,7 +14,7 @@
  * (enclosed in the file GPL).
  *)
 
-(*i $Id: html.ml,v 1.19 2003/09/30 07:57:30 filliatr Exp $ i*)
+(*i $Id: html.ml,v 1.20 2006/03/15 09:14:15 filliatr Exp $ i*)
 
 (*s Production of HTML syntax. *)
 
@@ -69,22 +69,8 @@ let is_absolute_url u =
   
 let is_relative_url u = not (is_absolute_url u)
 
-let quote_amp =
-  let re_qamp = Str.regexp_string "&amp;" in
-  let re_amp = Str.regexp_string "&" in
-  fun s -> 
-    let l = Str.split_delim re_qamp s in
-    let l = List.map (Str.global_replace re_amp "&amp;") l in
-    String.concat "&amp;" l
-
-let normalize_url u = 
-  if is_relative_url u && Filename.is_implicit u then
-    "./" ^ quote_amp u
-  else
-    quote_amp u
-
 let open_href ch s =
-  open_balise ch ("a href=\"" ^ (normalize_url s) ^ "\"")
+  open_balise ch ("a href=\"" ^ s ^ "\"")
 
 let close_href ch =
   close_balise ch "a"
