@@ -14,7 +14,7 @@
  * (enclosed in the file GPL).
  *)
 
-(*i $Id: latexmacros.ml,v 1.62 2007-03-21 14:25:56 filliatr Exp $ i*)
+(*i $Id: latexmacros.ml,v 1.65 2007-11-20 13:42:30 filliatr Exp $ i*)
 
 (*s This code is Copyright (C) 1997  Xavier Leroy. *)
 
@@ -93,6 +93,7 @@ def "\\textnormal" [Print_arg];
 def "\\mathnormal" [Print "<i>" ; Print_arg ; Print "</i>"];
 def "\\mathcal" [Print_arg];
 def "\\mathbb" [Print_arg];
+def "\\mathfrak" [Print_arg];
 
 def "\\textin" [Print "<sub>"; Print_arg; Print "</sub>"];
 def "\\textsu" [Print "<sup>"; Print_arg; Print "</sup>"];
@@ -204,9 +205,19 @@ def "\\`" [Raw_arg(function "e" -> print_s "&egrave;"
                           | s   -> print_s s)];
 def "\\~" [Raw_arg(function "n" -> print_s "&ntilde;"
 		          | "N" -> print_s "&Ntilde;"
+		          | "o" -> print_s "&otilde;"
+		          | "O" -> print_s "&Otilde;"
+		          | "a" -> print_s "&atilde;"
+		          | "A" -> print_s "&Atilde;"
 		          | ""  -> print_s "&tilde;"
                           | s   -> print_s s)];
+def "\\k" [Raw_arg(function "A" -> print_s "&#260;"
+                          | "a" -> print_s "&#261;"
+                          | "i" -> print_s "&#302;"
+                          | "I" -> print_s "&#303;"
+                          | s   -> print_s s)];
 def "\\c" [Raw_arg(function "c" -> print_s "&ccedil;"
+                          | "C" -> print_s "&Ccedil;"
                           | s   -> print_s s)];
 def "\\^" [Raw_arg(function "a" -> print_s "&acirc;"
                           | "A" -> print_s "&Acirc;"
@@ -219,6 +230,23 @@ def "\\^" [Raw_arg(function "a" -> print_s "&acirc;"
                           | "O" -> print_s "&Ocirc;"
                           | "u" -> print_s "&ucirc;"
                           | "U" -> print_s "&Ucirc;"
+                          | "w" -> print_s "&#x175;"
+                          | "W" -> print_s "&#x174;"
+                          | "y" -> print_s "&#x177;"
+                          | "Y" -> print_s "&#x176;"
+			  | ""  -> print_c '^'
+                          | s   -> print_s s)];
+def "\\hat" [Raw_arg(function "a" -> print_s "<em>&acirc;</em>"
+                          | "A" -> print_s "<em>&Acirc;</em>"
+                          | "e" -> print_s "<em>&ecirc;</em>"
+                          | "E" -> print_s "<em>&Ecirc;</em>"
+                          | "i" -> print_s "<em>&icirc;</em>"
+                          | "\\i" -> print_s "<em>&icirc;</em>"
+                          | "I" -> print_s "<em>&Icirc;</em>"
+                          | "o" -> print_s "<em>&ocirc;</em>"
+                          | "O" -> print_s "<em>&Ocirc;</em>"
+                          | "u" -> print_s "<em>&ucirc;</em>"
+                          | "U" -> print_s "<em>&Ucirc;</em>"
 			  | ""  -> print_c '^'
                           | s   -> print_s s)];
 def "\\\"" [Raw_arg(function "e" -> print_s "&euml;"
@@ -232,6 +260,8 @@ def "\\\"" [Raw_arg(function "e" -> print_s "&euml;"
                           | "O" -> print_s "&Ouml;"
                           | "u" -> print_s "&uuml;"
                           | "U" -> print_s "&Uuml;"
+                          | "y" -> print_s "&yuml;"
+                          | "Y" -> print_s "&Yuml;"
                           | s   -> print_s s)];
 def "\\u" [Raw_arg print_s ];
 def "\\v" [Raw_arg(function 
@@ -285,6 +315,18 @@ def "\\times" [Print "&#215;"];
 def "\\neg" [Print "&#172;"];
 def "\\frac" [Print "("; Print_arg; Print ")/("; Print_arg; Print ")"];
 
+(*** unicode characters
+def "\\models" [Print "&#X22A8;"];
+def "\\curlyvee" [Print "&#X22CE;"];
+def "\\curlywedge" [Print "&#X22CF"];
+def "\\infty" [Print "&infin;"];
+
+def "\\not" [Raw_arg (function
+  | "\\models" -> print_s "&#8877;"
+  | s -> print_s "not "; print_s s)];
+***)
+def "\\not" [Print "not "];
+
 (* Math symbols printed as texts (could we do better?) *)
 def "\\ne" [Print "=/="];
 def "\\in" [Print "in"];
